@@ -202,7 +202,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             {
                 if(spath[i] == '/') break;
             }
-            memcpy(sfname, spath + i + 1, len - i);
+            xstrncpy(sfname, spath + i + 1, PATH_MAX);
 
             /// get destination file name ///
             xstrncpy(dfile, dpath, PATH_MAX);
