@@ -128,12 +128,6 @@ static BOOL match_back(int start)
 
 #else
 
-    if(gMigemoCache == NULL) {
-        gReg = NULL;
-        mfiler4_migemo_init();
-        gMigemoCache = HASH_NEW_MALLOC(100);
-    }
-
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
@@ -262,12 +256,6 @@ static BOOL match_next(int start)
 
 #else
 
-    if(gMigemoCache == NULL) {
-        gReg = NULL;
-        mfiler4_migemo_init();
-        gMigemoCache = HASH_NEW_MALLOC(100);
-    }
-
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
@@ -457,11 +445,13 @@ static void mfiler4_migemo_init()
 
 void isearch_init()
 {
-    gInputFileName = STRING_NEW_MALLOC("");
+    gInputFileName = STRING_NEW_STACK("");
 
 #if defined(HAVE_MIGEMO_H)
-    gMigemoCache = NULL;
+    gMigemoCache = HASH_NEW_STACK(100);
     gReg = NULL;
+    gKanjiCode = kUtf8;
+    mfiler4_migemo_init();
 #endif
 }
 
@@ -483,11 +473,8 @@ void isearch_final()
 
             it = hash_loop_next(it);
         }
-        hash_delete_malloc(gMigemoCache);
     }
 #endif
-
-    string_delete_malloc(gInputFileName);
 }
 
 ///////////////////////////////////////////////////
@@ -495,14 +482,6 @@ void isearch_final()
 ///////////////////////////////////////////////////
 void isearch_input(int meta, int key)
 {
-#if defined(HAVE_MIGEMO_H)
-    if(gMigemoCache == NULL) {
-        gReg = NULL;
-        mfiler4_migemo_init();
-        gMigemoCache = HASH_NEW_MALLOC(100);
-    }
-#endif
-
     if(key == 8 || key == KEY_BACKSPACE || key == KEY_DC) {
         string_erase(gInputFileName, string_length(gInputFileName)-1, 1);
 #if defined(HAVE_MIGEMO_H)
@@ -619,6 +598,16 @@ void isearch_input(int meta, int key)
 ///////////////////////////////////////////////////
 // インクリメンタルサーチ描写
 ///////////////////////////////////////////////////
+#if defined(__CYGWIN__)
+void isearch_view()
+{
+    const int maxx = mgetmaxx();
+    const int maxy = mgetmaxy();
+
+    mbox(maxy/2, maxx/3, maxx/3, 3);
+    mvprintw(maxy/2+1, maxx/3+1, "/%s", string_c_str(gInputFileName));
+}
+#else
 void isearch_view()
 {
     const int maxx = mgetmaxx();
@@ -644,4 +633,5 @@ void isearch_view()
     buf[i] = 0;
     printw(buf);
 }
+#endif
 
